function y_f = band2freq(y_b, f)
% BAND2FREQ Calculate data from critical bands to frequencies
%
%   YF = BAND2FREQ(YB, F) Calculates the values given for critical bands in 
%           the vector YB at the frquencies given in the vector F in Hertz
%           units. If the input YB is NxK, F is Mx1, the output YF is MxK.
%
%           The result matrix YF contains the original values of YB spread
%           as defined by the frequeny vector F. If multiple values of F
%           are in the same critical band, the corresponding data of YB are
%           simply repeated.
%
%   This function can be used for calculating the number of bits used for
%   each spectral bin from the number of bits given in the critical bands,
%   for example.
%
%   See also: critical_bands, critical_band_index

% Allocate 
N_out = length(f);
N_blocks = size(y_b, 2);

y_f = nan(N_out, N_blocks);
[~, N_bands] = critical_bands();
band_idx = critical_band_index(f);

% Fill the bit_gain for each bin
for k = 1 : N_bands
    idx = (band_idx == k);
    y_f(idx, :) = repmat(y_b(k, :), sum(idx), 1);
end

end % of function band2freq
