function [cmp1, cmp2] = cmp_matrices(N_fft)
%CMP_MATRICES Comparison matrices for tonal set and masker calculation
%
%   [CMP1, CMP2] = CMP_MATRICES(N) Assembles the comparison matrices CMP1
%       and CMP2 for the selection of tonal components. The comparison
%       matrix CMP1 selects the neighboring bins of a frequency bin, while
%       CMP2 selects also farther neighbors. The i-th row of the comparison 
%       matrices selects the bins to be compared with the i-th bin.
%
%   Note: Faster sparse matrix assembly is used to increase the speed.
%
%   See also: maskers, tonal_set

% Assemble comparison matrix
cmp1 = spdiags(true(N_fft/2+1,2), [-1 1], N_fft/2+1, N_fft/2+1);

ranges = floor([0, N_fft/8, N_fft/4, N_fft/2+1]);
widths = floor(N_fft / 512 * [2, 3, 6]);
alldgs = [-max(widths) : -2, 2 : max(widths)];
vals   = false(N_fft/2+1, length(alldgs));

for i_range = 1 : numel(widths)
    rows = ranges(i_range)+1 : ranges(i_range+1);
    dgs = [-widths(i_range): -2, 2 : widths(i_range)];
    [~, cols] = ismember(dgs, alldgs);
    vals(rows, cols) = true;
end

cmp2 = logical(spdiags(vals, alldgs, N_fft/2+1, N_fft/2+1));

end % of function cmp_matrices
