function [idx] = critical_band_index(f)
% CRITICAL_BAND_INDEX Critical band indices for a frequency vector
%
%   IDX = CRITICAL_BAND_INDEX(F) Gives the critical band indices for the
%           frequency vector F. F should be given in Hertz units. IDX is a
%           vector of the frequency band indices, to which the values in F
%           belong. IDX will have the same size as F.
%
%   See also: critical_bands

f_c = critical_bands();
f_lims = [(f_c(2:end) + f_c(1:end-1))/2; max(f)];

idx = zeros(length(f), 1);
for i = 1 : length(f)
    idx(i) = find(f_lims >= f(i), 1, 'first');
end

end % of function critical_band_index
