function TG = global_masking_thresholds(T_TM, T_NM, TQ, mask_sel)
% GLOBAL_MASKING_THRESHOLDS Global masking thresholds over frequencies
%   
%   The global masking threshold curve is the sum of the threshold curves
%   from the human threshold in quiet, the tonal masking curves and the
%   noise masking curves.
%
%   TG = global_masking_threshols(T_TM, T_NM, TQ, MASK_SEL) Computes the
%       global masking threshold curve TG based on the set of tonal maskers
%       T_TM, noise maskers T_NM and the hearing thresold in quiet TQ.
%       The input vector MASK_SEL tells which masker should be taken into
%       account for a given frequency band. The elements of MASK_SEL can 
%       take three different values
%           0: No masker is taken from the given band
%           1: The tonal masker is used
%           2: The noise masker is used
%
%   See also: hearing_threshold, masking_thresholds, reorganize_maskers,
%       tonal_set

% Sum power of tonal and noise maskers
T_TM(isnan(T_TM)) = -inf;
T_NM(isnan(T_NM)) = -inf;

TM_sum = sum(10.^(0.1*T_TM(:, mask_sel == 1)), 2);
NM_sum = sum(10.^(0.1*T_NM(:, mask_sel == 2)), 2);

TG = 10*log10(10.^(0.1*TQ) + TM_sum + NM_sum);

end % of function global_masking_thresholds
