function [Tq, Tq_parts] = hearing_threshold(f)
% HEARING_THRESHOLD Calculate hearing threshold curve in quiet.
%
%   The hearing threshold gives the minimal audible level as an 
%   approximation of the Fletcher-Munson curves. The minimal level is 
%   strongly frequency dependent. This function gives the estimated hearing 
%   threshold of a young listener with unimpaired hearing.
%
%   [TQ, TQ_PARTS] = HEARING_THRESHOLD(F) Gives the hearing threshold level
%       TQ in sound pressure level decibels (dBSPL) for the frequencies 
%       given in Hz units in F. The second output TQ_PARTS gives the three 
%       components of the hearing threshold curves separately.

% Convert to kilohertz
fk = f(:) / 1000;

% The three parts of the function (low, mid, high frequencies)
Tq_parts = [3.64 * fk.^(-0.8),  -6.5*exp(-0.6*(fk-3.3).^2),  1e-3*fk.^4];
% The result is the sum of the three components
Tq = sum(Tq_parts, 2);

end % of function hearing_threshold
