function bark = hz2bark(hz)
% HZ2BARK Convert Hertz to Bark units
%
% The bark scale is a frequency scale on which equal distances correspond 
% with perceptually equal distances. Above about 500 Hz this scale is more 
% or less equal to a logarithmic frequency axis. Below 500 Hz the Bark 
% scale becomes more and more linear.
%
% The scale ranges from 1 to 24 and corresponds to the first 24 critical 
% bands of hearing.
%
%   BARK = HZ2BARK(HZ) Converts the frequency values given in Hertz units
%       in HZ to the Bark scale units in the result BARK.
%
%   See also: critical_bands

% Conversion rule
bark = 13*atan(.00076*hz)+3.5*atan((hz/7500).^2);

end % of function hz2bark
