function plot_maskers(fs, P, Tq, P_mask, mask_sel, TG, T_TM, T_NM)
%PLOT_MASKERS Plot the masking curves
%
%   This is a helper function that can is called if the proper plotting
%   option is selected in the function ANALYZE_SLICE. See the function 
%   ANALYZE_SLICE for further details.
%
%   See also: analyze_slice

N_fft = (length(P)-1)*2;
f = (0 : N_fft/2).'/N_fft*fs;

b = hz2bark(f);

tonal_idx = find(mask_sel == 1);
noise_idx = find(mask_sel == 2);

h_P = plot(b, P, 'LineWidth', 1.2);    % Plot Spectral power
hold on;
h_Tq = plot(b, Tq, '--', 'LineWidth', 1.5);   % Plot hearing threshold

% Plot tonal maskers
h_TM = plot(b(tonal_idx), P_mask(tonal_idx), ...
    'rx', 'LineWidth', 2);     
h_NM = plot(b(noise_idx), P_mask(noise_idx), ...
    'ko', 'LineWidth', 2, 'MarkerSize', 3);           % Plot noise maskers
h_TG = plot(b, TG, 'LineWidth', 1.5, 'Color', [0 .5 0]);
if (~isempty(tonal_idx))
    h_TMc = plot(b, T_TM(:, tonal_idx), 'r');
else
    h_TMc = plot(nan, nan);
end

if (~isempty(noise_idx))
    h_NMc = plot(b, T_NM(:, noise_idx), 'k');
else
    h_NMc = plot(nan, nan);
end
%plot(hz2bark(f), SFp(:,tonal_idx), '--');
ylim([-10 100]);
%title('Tonal and noise maskers with individual thresholds');
xlabel('Bark scale [-]');
ylabel('Level [dBSPL]');

legend([h_P, h_TM, h_NM, h_TMc(1), h_NMc(1), h_Tq, h_TG], ...
    {'Spectral power', 'Tonal maskers', 'Noise maskers', ...
    'Tonal masking curves', 'Noise masking curves', 'Hearing threshold', ...
    'Global masking curve'}, ...
    'Location', 'NorthWest');

set(gca, 'XGrid', 'On', 'YGrid', 'On');

if 1
    ax1_pos = get(gca, 'Position');
    bark_lim = get(gca, 'XLim');
    freq_ax = axes('Position',ax1_pos,...
        'XAxisLocation','top',...
        'YAxisLocation','right',...
        'Color','none');
    xlim(freq_ax, bark_lim);
    f_tick = [50 200 500 1000 2000 5000 10000 20000];
    f_ticklabel = {'50', '200', '500', '1k', '2k', '5k', '10k', '20k'};
    b_tick = hz2bark(f_tick);
    set(freq_ax, 'XTick', b_tick);
    set(freq_ax, 'XTickLabel', f_ticklabel);
    set(freq_ax, 'YTick', []);
    
    xlabel(freq_ax, 'Frequency [Hz]');
    
end

end

