function plot_nmr(f, TG, TG_crit, bits)
%PLOT_NMR Plot the noise to mask ratio and bit numbers
%  
%   This is a helper function that can is called if the proper plotting
%   option is selected in the function ANALYZE_SLICE. See the function 
%   ANALYZE_SLICE for further details.
%
%   See also: analyze_slice

if nargin < 4
    bits = 16;
end

b = hz2bark(f);

hold on;

n_crit = length(TG_crit);
b_step = [(0 : n_crit-1); (1 : n_crit)];
b_step = b_step(:);

TG_step = repmat(TG_crit(:).', 2, 1);
TG_step = TG_step(:);

NMR = TG_crit - (-6*(bits-16));
% Number of bits to gain is proportional to the NMR 
bit_gain = max(min(floor(NMR/6), bits), 0);

h_bars = bar((1:n_crit)-0.5, bit_gain*6, 1, ...
    'EdgeColor', 'k', 'FaceColor', [.8 .8 .8], ...
    'LineWidth', 1);

for i_crit = 1 : n_crit
    if bit_gain(i_crit) > 0
        text(i_crit-0.5, bit_gain(i_crit)*3, sprintf('%d', bit_gain(i_crit)), ...
            'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', ...
            'FontSize', 12, 'FontWeight', 'bold');
    end
end

ylim([-10 100]);

h_crit = plot(b_step, TG_step, 'LineWidth', 1.5, 'Color', 'r');
h_TG = plot(b, TG, 'LineWidth', 1.5, 'Color', [0 .5 0]);

h_noise = plot([0 n_crit], [0 0], 'LineWidth', 2, 'Color', 'b', 'LineStyle', ':');

xlabel('Bark scale [-]');
ylabel('Level [dBSPL]');

legend([h_TG, h_crit, h_noise, h_bars], ...
    {'Global masking threshold', 'Threshold in critcial bands', ...
    'Noise level', 'Bit gain in critical bands'}, ...
    'Location', 'NorthWest');

set(gca, 'XGrid', 'On', 'YGrid', 'On');


if 1
    ax1_pos = get(gca, 'Position');
    bark_lim = get(gca, 'XLim');
    freq_ax = axes('Position',ax1_pos,...
        'XAxisLocation','top',...
        'YAxisLocation','right',...
        'Color','none');
    xlim(freq_ax, bark_lim);
    f_tick = [50 200 500 1000 2000 5000 10000 20000];
    f_ticklabel = {'50', '200', '500', '1k', '2k', '5k', '10k', '20k'};
    b_tick = hz2bark(f_tick);
    set(freq_ax, 'XTick', b_tick);
    set(freq_ax, 'XTickLabel', f_ticklabel);
    set(freq_ax, 'YTick', []);
    
    xlabel(freq_ax, 'Frequency [Hz]');
    
end

end % of function plot_nmr

