function x_out = requantize(x_in, b, b_out)
%REQUANTIZE Requantize samlples to reduce number of bits
%   
%   X_OUT = REQUANTIZE(X_IN, B, B_OUT) Requantizes the original sample X_IN
%       having the bit depth B to a new bit depth B_OUT. The output sample
%       X_OUT has the same size as X_IN.
%
%   Example:
%       fs = 44100;                             % Sampling frequency [Hz]
%       N = 512;                                % Number of samples
%       t = (0 : N-1).'/fs;                     % Time vector
%       f0 = 1300;                              % Signal frequency [Hz]
%       b = 16;                                 % Bit depth
%       b_out = 5;                              % New bit depth
%       A = 0.6;                                % Signal amplitude
%       x = 2^(b-1)*A*sin(2*pi*f0*t);           % The signal
%       y = requantize(x, b, b_out);            % Perform requantization
%       plot(t, [x, y, x-y]);                   % Plot samples and diff.

bit_gain = max(b - b_out, 0);
x_out = floor(abs(x_in) ./ 2.^bit_gain) .* 2.^bit_gain .* sign(x_in);

end % of function requantize
